@@ -141,7 +141,9 @@ class Transaction(Resource):
         "refund_id",
         "refunded_transaction_id",
         "retried",
+        "retried_transaction_id",
         "retrieval_reference_number",
+        "retry_ids",
         "service_fee_amount",
         "settlement_batch_id",
         "shipping_amount",
